@@ -1,12 +1,21 @@
 import torch
-from pretrainedmodels.models import squeezenet1_1
+import pytest
 from torch import nn
 
 import yann
 from yann.contrib.pretrained import PretrainedModelWrapper
 from yann.utils.timer import Timer
 
+PRETRAINED_INSTALLED = True
+try:
+  from pretrainedmodels.models import squeezenet1_1
+except ImportError:
+  PRETRAINED_INSTALLED = False
 
+
+@pytest.mark.skipif(
+  not PRETRAINED_INSTALLED,
+  reason='pretrainedmodels not instaled')
 def test_pretrained():
   timer = Timer(log=True)
 
@@ -17,9 +26,9 @@ def test_pretrained():
 
   inputs = torch.rand(1, 3, 255, 255)
 
-  with yann.evalmode(wrapped), timer.task('model predict'):
+  with yann.eval_mode(wrapped), timer.task('model predict'):
     outputs = wrapped.predict(inputs)
-  with yann.evalmode(model), timer.task('model predict'):
+  with yann.eval_mode(model), timer.task('model predict'):
     model_outputs = model(inputs)
 
   assert torch.all(outputs.logits == model_outputs)
