@@ -63,41 +63,3 @@ class Samples:
   def __iter__(self):
     return (*self.inputs, *self.targets)
 
-
-class Batch:
-  inputs: Inputs
-  targets: Targets
-
-  def __init__(self, inputs, targets, outputs=None):
-    self.inputs = inputs
-    self.targets = targets
-
-  def __iter__(self):
-    return (*self.inputs, *self.targets)
-
-  def to(self, device):
-    pass
-
-  @property
-  def size(self):
-    return len(self.inputs[0])
-
-
-  def items(self):
-    return []
-
-class DetectionBatch(Batch):
-  boxes: Inputs
-
-class SegmentationBatch(Batch):
-  masks: Inputs
-
-
-batches: List[Batch] = []
-for b in batches:
-  b.to(model.device)
-  inputs, targets = b
-
-  outputs = model(*inputs)
-  b.outputs = outputs
-
