@@ -1,5 +1,5 @@
 from torch.nn import Module
-
+from ..exceptions import ShapeInferenceError
 
 class Reshape(Module):
   method = None
@@ -24,7 +24,7 @@ class Squeeze(Reshape):
   method = 'squeeze'
 
 
-class Permut1e(Reshape):
+class Permute(Reshape):
   method = 'permute'
 
 
@@ -58,14 +58,26 @@ def flatten_sequence(seq_batch):
 class Infer(Module):
   def __init__(self, cls, *args, **kwargs):
     super(Infer, self).__init__()
+    self.shape_dim = kwargs.pop('shape_dim', 1)
     self.cls = cls
-
     self.args = args
     self.kwargs = kwargs
 
     self.module = None
 
+  @property
+  def was_inferred(self):
+    return self.module is not None
+
   def forward(self, x):
     if self.module is None:
-      self.module = self.cls(x.shape[1], *self.args, **self.kwargs)
+      try:
+        self.module = self.cls(x.shape[self.shape_dim], *self.args, **self.kwargs)
+      except IndexError as e:
+        raise ShapeInferenceError(f"Improper shape dim ({self.shape_dim}) selected for {self.cls} with input of shape {x.shape}")
     return self.module(x)
+
+  @classmethod
+  def shed(cls, module):
+    # TODO: modify the model to drop the Infer nodes and replace them with the initialized module
+    raise NotImplementedError()
\ No newline at end of file
