@@ -4,6 +4,7 @@ import typing
 
 Logits = torch.FloatTensor
 Embedding = torch.FloatTensor
+OneHot = torch.Tensor
 
 Probabilities = torch.FloatTensor
 LogProbabilities = torch.FloatTensor
@@ -12,6 +13,7 @@ Batch = typing.NewType('Batch', torch.Tensor)
 
 ClassIndices = torch.LongTensor
 OneHot = torch.FloatTensor
+MultiLabelOneHot = OneHot
 
 ImageTensor = torch.ShortTensor
 NormalizedImageTensor = torch.FloatTensor
